pub struct ContractActionDesc<Hash, TargetId, AccountId> {
pub action_id: Hash,
pub target_id: Option<TargetId>,
pub to: Option<AccountId>,
}Fields
action_id: Hashtarget_id: Option<TargetId>to: Option<AccountId>Trait Implementations
Sourceimpl<Hash: Clone, TargetId: Clone, AccountId: Clone> Clone for ContractActionDesc<Hash, TargetId, AccountId>
impl<Hash: Clone, TargetId: Clone, AccountId: Clone> Clone for ContractActionDesc<Hash, TargetId, AccountId>
Sourcefn clone(&self) -> ContractActionDesc<Hash, TargetId, AccountId>
fn clone(&self) -> ContractActionDesc<Hash, TargetId, AccountId>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<Hash: Debug, TargetId: Debug, AccountId: Debug> Debug for ContractActionDesc<Hash, TargetId, AccountId>
impl<Hash: Debug, TargetId: Debug, AccountId: Debug> Debug for ContractActionDesc<Hash, TargetId, AccountId>
Sourceimpl<Hash, TargetId, AccountId> Decode for ContractActionDesc<Hash, TargetId, AccountId>
impl<Hash, TargetId, AccountId> Decode for ContractActionDesc<Hash, TargetId, AccountId>
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de, Hash, TargetId, AccountId> Deserialize<'de> for ContractActionDesc<Hash, TargetId, AccountId>
impl<'de, Hash, TargetId, AccountId> Deserialize<'de> for ContractActionDesc<Hash, TargetId, AccountId>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<Hash, TargetId, AccountId> Encode for ContractActionDesc<Hash, TargetId, AccountId>
impl<Hash, TargetId, AccountId> Encode for ContractActionDesc<Hash, TargetId, AccountId>
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl<Hash: Hash, TargetId: Hash, AccountId: Hash> Hash for ContractActionDesc<Hash, TargetId, AccountId>
impl<Hash: Hash, TargetId: Hash, AccountId: Hash> Hash for ContractActionDesc<Hash, TargetId, AccountId>
Sourceimpl<Hash: PartialEq, TargetId: PartialEq, AccountId: PartialEq> PartialEq for ContractActionDesc<Hash, TargetId, AccountId>
impl<Hash: PartialEq, TargetId: PartialEq, AccountId: PartialEq> PartialEq for ContractActionDesc<Hash, TargetId, AccountId>
Sourcefn eq(&self, other: &ContractActionDesc<Hash, TargetId, AccountId>) -> bool
fn eq(&self, other: &ContractActionDesc<Hash, TargetId, AccountId>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<Hash, TargetId, AccountId> Serialize for ContractActionDesc<Hash, TargetId, AccountId>
impl<Hash, TargetId, AccountId> Serialize for ContractActionDesc<Hash, TargetId, AccountId>
Sourceimpl<Hash, TargetId, AccountId> TypeInfo for ContractActionDesc<Hash, TargetId, AccountId>
impl<Hash, TargetId, AccountId> TypeInfo for ContractActionDesc<Hash, TargetId, AccountId>
impl<Hash, TargetId, AccountId> EncodeLike for ContractActionDesc<Hash, TargetId, AccountId>
impl<Hash: Eq, TargetId: Eq, AccountId: Eq> Eq for ContractActionDesc<Hash, TargetId, AccountId>
impl<Hash, TargetId, AccountId> StructuralPartialEq for ContractActionDesc<Hash, TargetId, AccountId>